@@ -34,10 +34,12 @@ class _HAProxyListenMariaDBFactory(_HAProxyListenFactory):
         )
 
     cluster = factory.SubFactory(
-        "cyberfusion.ClusterSupport.tests_factories.clusters.ClusterDatabaseFactory"
+        "cyberfusion.ClusterSupport.tests_factories.clusters.ClusterFactory"
     )
     cluster_id = factory.SelfAttribute("cluster.id")
-    destination_cluster = factory.SelfAttribute("cluster")
+    destination_cluster = factory.SubFactory(
+        "cyberfusion.ClusterSupport.tests_factories.clusters.ClusterDatabaseFactory"
+    )
     destination_cluster_id = factory.SelfAttribute("destination_cluster.id")
     load_balancing_method = factory.fuzzy.FuzzyChoice(LoadBalancingMethod)
     nodes_group = NodeGroup.MARIADB
@@ -55,10 +57,12 @@ class _HAProxyListenMeilisearchFactory(_HAProxyListenFactory):
         )
 
     cluster = factory.SubFactory(
-        "cyberfusion.ClusterSupport.tests_factories.clusters.ClusterDatabaseFactory"
+        "cyberfusion.ClusterSupport.tests_factories.clusters.ClusterFactory"
     )
     cluster_id = factory.SelfAttribute("cluster.id")
-    destination_cluster = factory.SelfAttribute("cluster")
+    destination_cluster = factory.SubFactory(
+        "cyberfusion.ClusterSupport.tests_factories.clusters.ClusterDatabaseFactory"
+    )
     destination_cluster_id = factory.SelfAttribute("destination_cluster.id")
     load_balancing_method = factory.fuzzy.FuzzyChoice(LoadBalancingMethod)
     nodes_group = NodeGroup.MEILISEARCH
@@ -76,10 +80,12 @@ class _HAProxyListenPostgreSQLFactory(_HAProxyListenFactory):
         )
 
     cluster = factory.SubFactory(
-        "cyberfusion.ClusterSupport.tests_factories.clusters.ClusterDatabaseFactory"
+        "cyberfusion.ClusterSupport.tests_factories.clusters.ClusterFactory"
     )
     cluster_id = factory.SelfAttribute("cluster.id")
-    destination_cluster = factory.SelfAttribute("cluster")
+    destination_cluster = factory.SubFactory(
+        "cyberfusion.ClusterSupport.tests_factories.clusters.ClusterDatabaseFactory"
+    )
     destination_cluster_id = factory.SelfAttribute("destination_cluster.id")
     load_balancing_method = factory.fuzzy.FuzzyChoice(LoadBalancingMethod)
     nodes_group = NodeGroup.POSTGRESQL
@@ -97,10 +103,12 @@ class _HAProxyListenRabbitMQFactory(_HAProxyListenFactory):
         )
 
     cluster = factory.SubFactory(
-        "cyberfusion.ClusterSupport.tests_factories.clusters.ClusterDatabaseFactory"
+        "cyberfusion.ClusterSupport.tests_factories.clusters.ClusterFactory"
     )
     cluster_id = factory.SelfAttribute("cluster.id")
-    destination_cluster = factory.SelfAttribute("cluster")
+    destination_cluster = factory.SubFactory(
+        "cyberfusion.ClusterSupport.tests_factories.clusters.ClusterDatabaseFactory"
+    )
     destination_cluster_id = factory.SelfAttribute("destination_cluster.id")
     load_balancing_method = factory.fuzzy.FuzzyChoice(LoadBalancingMethod)
     nodes_group = NodeGroup.RABBITMQ
@@ -118,15 +126,43 @@ class _HAProxyListenSingleStoreFactory(_HAProxyListenFactory):
         )
 
     cluster = factory.SubFactory(
-        "cyberfusion.ClusterSupport.tests_factories.clusters.ClusterDatabaseFactory"
+        "cyberfusion.ClusterSupport.tests_factories.clusters.ClusterFactory"
     )
     cluster_id = factory.SelfAttribute("cluster.id")
-    destination_cluster = factory.SelfAttribute("cluster")
+    destination_cluster = factory.SubFactory(
+        "cyberfusion.ClusterSupport.tests_factories.clusters.ClusterDatabaseFactory"
+    )
     destination_cluster_id = factory.SelfAttribute("destination_cluster.id")
     load_balancing_method = factory.fuzzy.FuzzyChoice(LoadBalancingMethod)
     nodes_group = NodeGroup.SINGLESTORE
 
 
+class _HAProxyListenWithNodesIdsFactory(_HAProxyListenFactory):
+    """Factory for specific object with nodes_ids."""
+
+    class Meta:
+        """Settings."""
+
+        exclude = (
+            "cluster",
+            "destination_cluster",
+            "node",
+        )
+
+    cluster = factory.SubFactory(
+        "cyberfusion.ClusterSupport.tests_factories.clusters.ClusterFactory"
+    )
+    cluster_id = factory.SelfAttribute("cluster.id")
+    destination_cluster = factory.SelfAttribute("node.cluster")
+    destination_cluster_id = factory.SelfAttribute("destination_cluster.id")
+    load_balancing_method = factory.fuzzy.FuzzyChoice(LoadBalancingMethod)
+    node = factory.SubFactory(
+        "cyberfusion.ClusterSupport.tests_factories.nodes.NodeMariaDBFactory"
+    )
+    nodes_ids = factory.LazyAttribute(lambda o: [o.node.id])
+    nodes_group = factory.LazyAttribute(lambda o: o.node.groups[0])
+
+
 class HAProxyListenMariaDBPortFactory(_HAProxyListenMariaDBFactory):
     """Factory for specific object."""
 
@@ -134,6 +170,13 @@ class HAProxyListenMariaDBPortFactory(_HAProxyListenMariaDBFactory):
     port = 3306
 
 
+class HAProxyListenMariaDBPortNodesIdsFactory(_HAProxyListenWithNodesIdsFactory):
+    """Factory for specific object."""
+
+    socket_path = None
+    port = 3306
+
+
 class HAProxyListenMariaDBSocketPathFactory(_HAProxyListenMariaDBFactory):
     """Factory for specific object."""
 
